@@ -1,5 +1,4 @@
-# @(#)$Id: CPANTesting.pm 176 2013-02-10 17:27:58Z pjf $
-# Bob-Version: 1.7
+# @(#)Ident: CPANTesting.pm 2013-07-29 15:46 pjf ;
 
 package CPANTesting;
 
@@ -13,14 +12,19 @@ sub is_testing { !! ($ENV{AUTOMATED_TESTING} || $ENV{PERL_CR_SMOKER_CURRENT}
                  || ($ENV{PERL5OPT} || q()) =~ m{ CPAN-Reporter }mx) }
 
 sub should_abort {
+   is_testing() or return 0;
+
+   $host eq q(xphvmfred) and return
+      "ABORT: ${host} - cc06993e-a5e9-11e2-83b7-87183f85d660";
    return 0;
 }
 
 sub test_exceptions {
    my $p = shift; is_testing() or return 0;
 
-   $p->{stop_tests}     and return 'CPAN Testing stopped in Build.PL';
-   $osname eq q(mirbsd) and return 'Mirbsd  OS unsupported';
+   $p->{stop_tests}     and return 'TESTS: CPAN Testing stopped in Build.PL';
+   $osname eq q(mirbsd) and return 'TESTS: Mirbsd OS unsupported';
+#  $host   eq q(broken) and return "tests: <CPAN Testing uuid>";
    return 0;
 }
 
